@@ -12,7 +12,7 @@
 <context>
     <name>CacheProvider</name>
     <message>
-        <location filename="../src/cacheprovider.cpp" line="381"/>
+        <location filename="../src/cacheprovider.cpp" line="388"/>
         <source>&amp;Cache Provider</source>
         <translation>&amp;Cache-Datenquelle</translation>
     </message>
@@ -202,32 +202,36 @@
 <context>
     <name>GcBrowser</name>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="103"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="120"/>
         <source>No valid login specified, cache positions will be inaccurate!</source>
         <translation>Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="235"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="254"/>
         <source>!Network connection failed, please make sure you are connected to the internet and restart CacheMe!</source>
         <translation>!Netzwerkverbindung fehlgeschlagen. Bitte stellen Sie sicher, dass Sie mit dem Netzwerk verbunden sind und starten Sie CacheMe neu!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="275"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="287"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="325"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="337"/>
         <source>Login failed!</source>
         <translation>Einloggen fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="478"/>
-        <source>Unable to determine cache id!</source>
-        <translation>Cache-ID nicht feststellbar!</translation>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="509"/>
+        <source>Too many caches at this zoom level, please zoom in.</source>
+        <translation>Zu viele Caches in dieser Zoomstufe.</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="506"/>
+        <source>Unable to determine cache id!</source>
+        <translation type="obsolete">Cache-ID nicht feststellbar!</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="593"/>
         <source>Unable to determine cache guid!</source>
         <translation>Cache-Guid nicht feststellbar!</translation>
     </message>
@@ -301,23 +305,19 @@
 <context>
     <name>GcParser</name>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="310"/>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="318"/>
         <source>Too many caches</source>
-        <translation>Zu viele Caches</translation>
+        <translation type="obsolete">Zu viele Caches</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="311"/>
         <source>No caches in this area</source>
-        <translation>Keine Caches in dieser Gegend</translation>
+        <translation type="obsolete">Keine Caches in dieser Gegend</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="381"/>
         <source>Error downloading caches</source>
-        <translation>Fehler beim Laden der Caches</translation>
+        <translation type="obsolete">Fehler beim Laden der Caches</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="451"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="409"/>
         <source>Error downloading cache info</source>
         <translation>Fehler beim Download der Cache-Info</translation>
     </message>
@@ -434,17 +434,22 @@
         <translation type="obsolete">&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="49"/>
+        <location filename="../src/mainwindow.cpp" line="60"/>
         <source>&amp;Settings</source>
         <translation>&amp;Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="48"/>
+        <location filename="../src/mainwindow.cpp" line="55"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="55"/>
+        <location filename="../src/mainwindow.cpp" line="57"/>
+        <source>&amp;MotD</source>
+        <translation>&amp;NdT</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="66"/>
         <source>&amp;Tools</source>
         <translation>&amp;Werkzeuge</translation>
     </message>
@@ -453,50 +458,55 @@
         <translation type="obsolete">&amp;Rot13/Cäsar</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="81"/>
+        <location filename="../src/mainwindow.cpp" line="149"/>
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="98"/>
+        <location filename="../src/mainwindow.cpp" line="166"/>
         <source>About CacheMe</source>
         <translation>Über CacheMe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="99"/>
-        <location filename="../src/mainwindow.cpp" line="114"/>
+        <location filename="../src/mainwindow.cpp" line="167"/>
+        <location filename="../src/mainwindow.cpp" line="198"/>
         <source>CacheMe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="99"/>
+        <location filename="../src/mainwindow.cpp" line="167"/>
         <source>Version</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="100"/>
+        <location filename="../src/mainwindow.cpp" line="168"/>
         <source>Build date:</source>
         <translation>Erstellungsdatum:</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="101"/>
+        <location filename="../src/mainwindow.cpp" line="169"/>
         <source>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;</source>
         <oldsource>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;
 </oldsource>
         <translation>(c) 2011 von Till Harbaum &lt;till@harbaum.org&gt;</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="102"/>
+        <location filename="../src/mainwindow.cpp" line="170"/>
         <source>CacheMe is an online geocaching application.</source>
         <translation>CacheMe ist eine Online-Geocaching-Anwendung.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="219"/>
+        <location filename="../src/mainwindow.cpp" line="180"/>
+        <source>Message of the day</source>
+        <translation>Nachricht des Tages</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="304"/>
         <source>This copy of CacheMe has expired and will close in one minute!</source>
         <translation>Diese Kopie von CacheMe ist abgelaufen und wird in einer Minute geschlossen!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="222"/>
+        <location filename="../src/mainwindow.cpp" line="307"/>
         <source>This copy of CacheMe will expire in %1 days!</source>
         <translation>Diese Kopie von CacheMe läuft in %1 Tagen aus!</translation>
     </message>
@@ -1325,7 +1335,7 @@
         <translation>&lt;unbekannt&gt;</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="200"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="219"/>
         <source>GPL version 2
 Copyright 2011 by Till Harbaum
 QSgml parts Copyright 2010 by Andreas Lehmann</source>
