@@ -1,7 +1,7 @@
 #include <QDebug>
 #include <QtPlugin>
 #include <QSettings>
-
+#include <math.h>
 
 #include <QDialog>
 #include <QGroupBox>
@@ -19,6 +19,23 @@
 
 #define PLUGIN_NAME "GcBrowser"
 
+// conversions from and to tile coordinates
+int long2tilex(double lon, int z)  { 
+  return (int)(floor((lon + 180.0) / 360.0 * pow(2.0, z))); 
+}
+ 
+int lat2tiley(double lat, int z) { 
+  return (int)(floor((1.0 - log( tan(lat * M_PI/180.0) + 1.0 / cos(lat * M_PI/180.0)) / M_PI) / 2.0 * pow(2.0, z))); 
+}
+ 
+double tilex2long(double x, int z)  {
+  return x / pow(2.0, z) * 360.0 - 180;
+}
+
+double tiley2lat(double y, int z)  {
+  double n = M_PI - 2.0 * M_PI * y / pow(2.0, z);
+  return 180.0 / M_PI * atan(0.5 * (exp(n) - exp(-n)));
+}
 
 // The GcUrl class automatically creates urls for geocaching.com
 class GcUrl : public QUrl {
@@ -152,6 +169,7 @@ GcBrowser::GcBrowser() : m_initialized(false), m_cacheList(PLUGIN_NAME),
   // setup network manager and listen for its replies
   this->m_manager = new QNetworkAccessManager(this);
 
+#if 0
   // get current list of ip addresses
   QNetworkConfigurationManager mgr;
   QNetworkSession session (mgr.defaultConfiguration());
@@ -165,6 +183,7 @@ GcBrowser::GcBrowser() : m_initialized(false), m_cacheList(PLUGIN_NAME),
   for ( QList<QNetworkAddressEntry> ::const_iterator it = laddr.begin(); it != laddr.end(); ++it ) {
     qDebug() << "Entry" << it->ip();
   }
+#endif
 
   // try to load stored cookies
   QList<QNetworkCookie> cookies;
@@ -254,14 +273,7 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
     QNetworkReply *newReply;
 
     // http 1.1 always builds a get request from a redirected get or post
-#if 0
-    if(this->m_posted.isEmpty())
-      newReply = this->m_manager->get(request);
-    else
-      newReply = this->m_manager->post(request, this->m_posted.toUtf8());
-#else
     newReply = this->m_manager->get(request);
-#endif
     
     if(newReply->error()) replyFinished(newReply);
     reply->deleteLater();
@@ -329,24 +341,66 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
       }
     } else {
       qDebug() << __FUNCTION__ << "reply";
-      
+
       // initialization is finished, any reply received now should
       // be a reply to a real request
       CurrentRequest type = this->m_currentRequest;
-      this->m_currentRequest = None;
 
-      emit done();
+      if(type != Overview) {
+	this->m_currentRequest = None;
+	emit done();
+      }
 
       if(!reply->error()) {
 	GcParser gcParser;
 	GcHtmlParser gcHtmlParser;
-	
+
 	switch(type) {
 	case Overview: 
-	  // start parser (and tell him whether we tried to load a "big" area)
-	  if(!gcParser.decodeOverview(allData, m_cacheList, m_bigArea))
-	    error(gcParser.error());
+	  qDebug() << __FUNCTION__ << "rcvd: " << allData.length();
 
+	  if((!m_tile_is_image) && (allData.length() > 0)) 
+	    if(!gcParser.decodeOverview(allData, m_overviewMap, 
+					m_tile_x_cur, m_tile_y_cur))
+	      error(gcParser.error());
+
+	  if(m_tile_is_image) 
+	    m_tile_is_image = false;
+	  else {
+	    m_tile_is_image = true;
+	    m_tile_x_cur++;
+	    if(m_tile_x_cur > m_tile_x_max) {
+	      m_tile_x_cur = m_tile_x_min;
+	      m_tile_y_cur++;
+	    }
+	  }
+	  
+	  if(!overviewDone())
+	    requestNextTile();
+	  else {
+	    this->m_currentRequest = None;
+	    emit done();
+
+	    m_cacheList.clear();
+	    QMap<QString, OverviewEntry>::iterator i = m_overviewMap.begin();
+	    while (i != m_overviewMap.end()) {
+	      OverviewEntry entry = i.value();
+
+	      // create cache entries from overview map
+	      Cache cache;
+	      
+	      cache.setDescription(entry.n);
+	      cache.setType(Cache::TypeTraditional);
+	      cache.setName(i.key());
+	      cache.setCoordinate(
+		 QGeoCoordinate(tiley2lat(entry.y/entry.c, m_tile_zoom),
+				tilex2long(entry.x/entry.c, m_tile_zoom)));
+
+	      m_cacheList.append(cache);
+	      ++i;
+	    }
+	    
+#if 0
 	  // append saved Waypoints if they belong to one of the caches
 	  // returned
 	  for(QList<Cache>::iterator i = m_cacheList.begin(); 
@@ -355,9 +409,14 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
 	      foreach(const Waypoint wpt, m_lastWaypoints)
 		i->appendWaypoint(wpt);
 
-	  // always emit the list, even if it's empty, so existing caches
-	  // get cleared
-	  emit replyOverview(m_cacheList);
+#endif
+
+	    // always emit the list, even if it's empty, so existing caches
+	    // get cleared
+	    emit replyOverview(m_cacheList);
+	    m_state = Idle;
+	  }
+	  
 	  break;
 	  
 	case Info: 
@@ -406,21 +465,56 @@ void GcBrowser::replyFinished(QNetworkReply *reply) {
   }
 }
 
-void GcBrowser::postJson(const QString &post) {
-  // build and send request
-  GcNetworkRequest request;
-  request.setUrl(GcUrl("/map/default.aspx/MapAction"));
-  request.setRawHeader("Accept", "application/json");
-  request.setRawHeader("Content-Type", "application/json; charset=utf-8");
-
-  this->m_posted = post;
-  m_manager->post(request, post.toUtf8());
-  emit notifyBusy(true);
+bool GcBrowser::overviewDone() {
+  return(m_tile_y_cur > m_tile_y_max);
 }
 
-void GcBrowser::processRequestOverview(const QGeoBoundingBox &area, const int) {
+void GcBrowser::requestNextTile() {
+  qDebug() << __FUNCTION__;
+
+  if(!overviewDone()) {
+    QString flagStr, type;
+
+    if(m_tile_is_image) type = "tile";
+    else                type = "info";
+
+#if 0 // not working yet
+    if(m_flags & CacheProvider::NoFound) flagStr += "&hf=1";
+    if(m_flags & CacheProvider::NoOwned) flagStr += "&hh=1";
+#endif
+
+    GcNetworkRequest request;
+    request.setUrl(GcUrl("/map/default.aspx/map." + type +
+			 "?x=" + QString::number(m_tile_x_cur) + 
+			 "&y=" + QString::number(m_tile_y_cur) + 
+			 "&z=" + QString::number(m_tile_zoom) + 
+			 flagStr));
+
+   qDebug() << request.url();
+    this->m_posted = QString();
+    QNetworkReply *reply = this->m_manager->get(request);    
+    emit notifyBusy(true);
+    if(reply->error()) replyFinished(reply);
+  }
+}
+
+void GcBrowser::processRequestOverview(const QGeoBoundingBox &area, const int zoom, const int flags) {
   qDebug() << __PRETTY_FUNCTION__;
 
+  // processing levels < 13 results in too much data to process on
+  // the phone
+  if(zoom < 13) {
+    m_cacheList.clear();
+
+    error(tr("Too many caches at this zoom level, please zoom in."));
+
+    emit done();
+    emit replyOverview(m_cacheList);
+    emit next();
+
+    return;
+  }
+
   // check if we can fulfil request from cachelist
   if(m_cacheBox.contains(area) && m_cacheList.size() > 0) {
     qDebug() << __FUNCTION__ << "can fulfil request from cache";
@@ -444,55 +538,48 @@ void GcBrowser::processRequestOverview(const QGeoBoundingBox &area, const int) {
 
   Q_ASSERT(this->m_currentRequest == None);
   this->m_currentRequest = Overview;
-  
-  // check if bounding box doesn't exceed limits (40km diagonally)
-  this->m_bigArea = area.topLeft().distanceTo(area.bottomRight()) > 40000;
-  
-  // build request string. Isn't there a way to not request "owned" and
-  // "found" ones?
-  postJson("{\"dto\":{\"data\":{\"c\":1,\"m\":\"\",\"d\":\"" + 
-	   QString::number(area.topLeft().latitude()) + "|" + 
-	   QString::number(area.bottomRight().latitude()) + "|" + 
-	   QString::number(area.bottomRight().longitude()) + "|" + 
-	   QString::number(area.topLeft().longitude()) + 
-	   "\"},\"ut\":\"" + this->m_userToken + "\"}}");
-}
 
-int GcBrowser::getCacheId(const QString &name) {
-  int id = -1;
+  // calculate tile bounds
+  m_tile_zoom = zoom;
+  m_tile_is_image = true;
+  m_flags = flags;
 
-  // try to find matching cache id
-  QList<Cache>::const_iterator i;
-  for( i = m_cacheList.begin(); i != m_cacheList.end(); ++i ) {
-    if(i->name() == name) {
-      id = i->id();
-      m_cache = *i;
-    }
-  }
+  // setup 
+  m_tile_x_min = long2tilex(area.topLeft().longitude(), m_tile_zoom);
+  m_tile_x_max = long2tilex(area.bottomRight().longitude(), m_tile_zoom);
+  m_tile_y_min = lat2tiley(area.topLeft().latitude(), m_tile_zoom);
+  m_tile_y_max = lat2tiley(area.bottomRight().latitude(), m_tile_zoom);
+  m_tile_x_cur = m_tile_x_min;
+  m_tile_y_cur = m_tile_y_min;
 
-  if(id < 0) {
-    // remove current request and continue with the next one
-    emit done();
-    emit next();
+  qDebug() << __FUNCTION__ << "Requesting tile area X:" <<
+    m_tile_x_min << m_tile_x_max << " Y:" << m_tile_y_min << m_tile_y_max;
 
-    error(tr("Unable to determine cache id!"));
-  }
-
-  return id;
+  m_state = ProcessingOverview;
+  m_overviewMap.clear();
+  requestNextTile();
 }
 
 void GcBrowser::processRequestInfo(const QString &name) {
+  GcNetworkRequest request;
+  
   qDebug() << __PRETTY_FUNCTION__ << name;
-
+  
   Q_ASSERT(this->m_currentRequest == None);
   this->m_currentRequest = Info;
   
-  int id = getCacheId(name);
-  if(id < 0) return;
-
-  postJson("{\"dto\":{\"data\":{\"c\":2,\"m\":\"\",\"d\":\"" + 
-	   QString::number(id) + 
-	   "\"},\"ut\":\"" + this->m_userToken + "\"}}");
+  // preset all present knowledge from cachelist (esp. coordinates)
+  QList<Cache>::const_iterator i;
+  for( i = m_cacheList.begin(); i != m_cacheList.end(); ++i )
+    if(i->name() == name)
+      m_cache = *i;
+  
+  request.setUrl(GcUrl("/map/default.aspx/map.details?i=" + name));
+  qDebug() << request.url();
+  this->m_posted = QString();
+  QNetworkReply *reply = this->m_manager->get(request);    
+  emit notifyBusy(true);
+  if(reply->error()) replyFinished(reply);
 }
 
 void GcBrowser::processRequestDetail(const QString &name) {
