@@ -209,10 +209,20 @@ void GcHtmlParser::parseLogDt(Log &log, const QSgmlTag::QSgmlTaglist &list) {
 
   QStringList words = text.split(' ');
 
+  qDebug() << __FUNCTION__ << words;
+
   // find the word "by"
   int by = words.indexOf("by");
-  if(by >= 0 && by+1 < words.size())
-    log.setFinder(words[by+1]);
+
+  // the words are "by" name ... "(xxx" "type)"
+  QString name;
+  while((by >= 0) && (by < words.size()-3)) {
+    if(!name.isEmpty()) name += " ";
+    name += words[++by];
+  }
+
+  if(!name.isEmpty())
+    log.setFinder(name);
 }
 
 void GcHtmlParser::parseLogDD(Log &log, const QSgmlTag::QSgmlTaglist &list) {
