@@ -1,6 +1,8 @@
 #include <QDebug>
 
+#include <QTextDocument>
 #include "gcparser.h"
+#include "gcbrowser.h"
 
 GcParser::GcParser() {
 }
@@ -54,10 +56,16 @@ bool GcParser::parseInt(const QMap<QString, QVariant> &map, const QString &key,
 // 2000: Parking, 2001: Trailhead, Stage of a Multicache, 
 // 2003: Question to answer, 2004: Reference Point, Final Location
 
-bool GcParser::parseCtid(const QMap<QString, QVariant> &map, 
+bool GcParser::parseType(const QMap<QString, QVariant> &map, 
 			 const QString &key, Cache::Type &val) {
+  QMap<QString, QVariant> imap;
   int i, ctid;
 
+  if(!parseMap(map, key, imap)) {
+    val = Cache::TypeUnknown;
+    return false;
+  }
+
   const struct { Cache::Type type; int ctid; } tags[] = {
     { Cache::TypeTraditional, 2 }, { Cache::TypeMulti,        3 },
     { Cache::TypeMystery,     8 }, { Cache::TypeVirtual,      4 },
@@ -67,7 +75,7 @@ bool GcParser::parseCtid(const QMap<QString, QVariant> &map,
     { Cache::TypeCito,       13 }, { Cache::TypeUnknown,     -1 }
   };
 
-  if(!parseInt(map, key, ctid)) {
+  if(!parseInt(imap, "value", ctid)) {
     val = Cache::TypeUnknown;
     return false;
   }
@@ -93,23 +101,35 @@ QString GcParser::subString(QString &str, const QString &start, const QString &e
 
 bool GcParser::parseRating(const QMap<QString, QVariant> &map, 
 			   const QString &key, Rating &rating) {
+  QMap<QString, QVariant> imap;
   QString ratingStr;
 
-  if(!parseString(map, key, ratingStr)) {
+  if(!parseMap(map, key, imap)) {
     rating.set(0);
     return false;
   }
 
-  rating.set(subString(ratingStr, "alt=\"", "\"").split(" ")[0].toFloat());
+  if(!parseString(imap, "text", ratingStr)) {
+    rating.set(0);
+    return false;
+  }
+  
+  rating.set(ratingStr.toFloat());
 
   return true;
 }
 
 bool GcParser::parseContainer(const QMap<QString, QVariant> &map, 
 			      const QString &key, Container &container) {
+  QMap<QString, QVariant> imap;
   QString containerStr;
   int i;
 
+  if(!parseMap(map, key, imap)) {
+    container.set(Container::ContainerUnknown);
+    return false;
+  }
+
   const struct { Container::Type type; QString str; } tags[] = {
     { Container::ContainerRegular, "Regular" }, 
     { Container::ContainerSmall,     "Small" },
@@ -121,12 +141,11 @@ bool GcParser::parseContainer(const QMap<QString, QVariant> &map,
     { Container::ContainerUnknown,       "?" }
   };
 
-  if(!parseString(map, key, containerStr)) {
+  if(!parseString(imap, "text", containerStr)) {
     container.set(Container::ContainerUnknown);
     return false;
   }
 
-  containerStr = subString(containerStr, "alt=\"", "\"").split(" ")[1];
   container.set(Container::ContainerRegular);
 
   for(i=0;(tags[i].type != Container::ContainerUnknown) && 
@@ -137,6 +156,19 @@ bool GcParser::parseContainer(const QMap<QString, QVariant> &map,
   return container.isSet();
 }
 
+bool GcParser::parseOwner(const QMap<QString, QVariant> &map, 
+			      const QString &key, QString &owner) {
+  QMap<QString, QVariant> imap;
+
+  if(!parseMap(map, key, imap)) 
+    return false;
+
+  if(!parseString(imap, "text", owner))
+    return false;
+  
+  return true;
+}
+
 bool GcParser::parseDate(const QMap<QString, QVariant> &map, 
 			 const QString &key, QDate &date) {
   QString dateStr;
@@ -232,100 +264,6 @@ bool GcParser::parseMap(const QMap<QString, QVariant> &map, const QString &key,
   return true;
 }
 
-bool GcParser::parseOverviewEntry(const QMap<QString, QVariant> &map, Cache &cache) {
-  
-  //  qDebug() << __FUNCTION__ << map;
-
-  // set coordinates
-  qreal lat, lon;
-  if(parseFloat(map, "lat", lat) && parseFloat(map, "lon", lon)) {
-    QGeoCoordinate coo(lat, lon);
-    cache.setCoordinate(coo);
-  }
-
-  // set name and description
-  QString nn, gc;
-  if(parseString(map, "nn", nn))   cache.setDescription(nn);
-  if(parseString(map, "gc", gc))   cache.setName(gc);
-
-  bool f, o, ia;
-  if(parseBool(map, "f", f))       cache.setFound(f);
-  if(parseBool(map, "o", o))       cache.setOwned(o);
-  if(parseBool(map, "ia", ia))     cache.setAvailable(ia);
- 
-  int id;
-  if(parseInt(map, "id", id))      cache.setId(id);
-
-  Cache::Type type;
-  if(parseCtid(map, "ctid", type)) cache.setType(type);
-
-//  qDebug() << __FUNCTION__ << cache;
-  
-  return true;
-}
-
-bool GcParser::parseOverviewCC(const QList<QVariant> &list, 
-			       CacheList &cacheList) {
-  bool retval = true;
-
-  QList<QVariant>::const_iterator it = list.begin();
-  while(it != list.end()) {
-
-    // the value of this entry should be a map
-    if(QVariant::Map != (*it).type()) 
-      qDebug() << __FUNCTION__ << "Ignoring unexpected value type:" << (*it).type();
-    else {
-      Cache cache;
-      QMap<QString, QVariant> map = (*it).toMap();
-      if(parseOverviewEntry(map, cache))
-	cacheList.append(cache);
-      else
-	retval = false;
-    }
-    it++;
-  }
-   
-  return retval;
-}
-
-bool GcParser::parseOverviewRoot(const QMap<QString, QVariant> &map, 
-				 CacheList &cacheList, bool bigArea) {
-  // the root overview has 6 fields:
-  // c:      int, unknown, always 1
-  // cc:     list of caches
-  // count:  int, number of entries
-  // dist:   float, ??
-  // li:     bool, ?? logged in? 
-  // pm:     bool, ??
-
-  qDebug() << __FUNCTION__;
-
-  int count = 0;
-  if(!parseInt(map, "count", count))
-    return false;
-
-  if(count == 0) {
-    // if the area is too big, the result will look exactly
-    // like one for an area without any cache
-    if(bigArea) m_error = tr("Too many caches");
-    else        m_error = tr("No caches in this area");
-
-    return false;
-  }
-
-  // the list will be empty if more than 500 caches are in this area
-  if(count > 500) {
-    m_error = tr("Too many caches");
-    return false;
-  }
-
-  QList<QVariant> list;
-  if(!parseList(map, "cc", list))
-    return false;
-
-  return parseOverviewCC(list, cacheList);
-}
-
 bool GcParser::decodeJson(const QString &data, QMap<QString, QVariant>&map) {
   bool ok;
 
@@ -346,119 +284,146 @@ bool GcParser::decodeJson(const QString &data, QMap<QString, QVariant>&map) {
   return true;
 }
 
-// stage two is a complex json encoded map stored under key "cs"
-bool GcParser::decodeStage2(const QString &data, QMap<QString, QVariant> &map) {
-  QMap<QString, QVariant> tmpMap;
-
-  if(!decodeJson(data, tmpMap))
-    return false;
-
-  if(!parseMap(tmpMap, "cs", map))
-    return false;
-
-  return true;
-}
-
 // stage one is just a single json encoded string stored under key "d"
-bool GcParser::decodeStage1(const QString &data, QString &string) {
-  QMap<QString, QVariant> map;
+bool GcParser::decodeOverview(const QString &data, QMap<QString, GcBrowser::OverviewEntry> &entryMap, int x, int y) {
+  QMap<QString, QVariant> map, map2;
+  GcBrowser::OverviewEntry entry;
 
   if(!decodeJson(data, map))
     return false;
 
-  if(!parseString(map, "d", string))
+  // the data map contains all information, we don't need "keys" and "grid"
+  if(!parseMap(map, "data", map2))
     return false;
 
+  // walk through all entries in the map
+  foreach(QString key, map2.keys()) {
+    QList<QVariant> list;
+    QString i;
+    QStringList pos = key.split("_");
+    if(pos.size() == 2) {
+      entry.x = x + pos[0].toInt()/64.0;
+      entry.y = y + pos[1].toInt()/64.0;
+      entry.c = 1;
+
+      if(parseList(map2, key, list)) {
+	if(list.size() >= 1) {
+	  int c;
+	  for(c=0;c<list.size();c++) {
+
+	    QMap<QString, QVariant> imap = list[c].toMap();
+	
+	    foreach(QString ikey, imap.keys()) {
+	      if(!ikey.compare("i")) 
+		i = imap.value(ikey).toString();
+	    
+	      if(!ikey.compare("n"))
+		entry.n = imap.value(ikey).toString();
+	    }
+	    
+	    // qDebug() << __FUNCTION__ << entry.x << entry.y << i << entry.n;
+	    
+	    // append to matching existing entry or create a new one
+	    if(entryMap.contains(i)) {
+	      GcBrowser::OverviewEntry old = entryMap.value(i);
+	      entry.x += old.x;
+	      entry.y += old.y;
+	      entry.c += old.c;
+	    }
+	    
+	    entryMap.insert(i, entry);
+	  }
+	} else
+	  qDebug() << __FUNCTION__ << "Warning, list len < 1:" << list.size();
+      } else
+	qDebug() << __FUNCTION__ << "Expected list";
+    } else
+      qDebug() << __FUNCTION__ << "Warning, grid len != 2:" << pos.size();
+  }
+
   return true;
 }
 
-bool GcParser::decodeOverview(const QString &data, 
-			      CacheList &cacheList, bool bigArea) {
-
-  cacheList.clear();
-
-  // assume for now that parsing failed for unknown reason
-  m_error = tr("Error downloading caches");
-
-  QString string;
-  if(!decodeStage1(data, string))
-    return false;
-
-  QMap<QString, QVariant> map; 
-  if(!decodeStage2(string, map))
-    return false;
-
-  if(parseOverviewRoot(map, cacheList, bigArea))
-    m_error = QString();
-
-  return(m_error.isNull());
-}
-
-
-
 bool GcParser::parseInfoEntry(const QMap<QString, QVariant> &map, Cache &cache) {
 
-  //  qDebug() << __FUNCTION__ << map;
+  /* unparsed entries:
+     "subrOnly":false,  // premium only
+     "li":false,        // 
+     "fp":"5",          // favourtite points
+  */
 
-  // the info entry has 19 fields:
-  // bm:     int, the id of the requested cache
-  // c:      int, unknown, always 2
-  // cb:     string, owner
-  // cburl:  string, owner url
-  // lg:     int, the id of the requested cache
-  // li:     bool, unknown (false)
-  // pm:     bool, unknown (false)
-  // tc:     int, unknown (1)
+  QString gc, name;
+  if(parseString(map, "gc", gc)) {
+    cache.setName(gc);
+    cache.setUrl("http://www.geocaching.com/seek/cache_details.aspx?wp=" + gc);
+  }
 
-  QString cgc, cn;
-  if(parseString(map, "cgc", cgc)) cache.setName(cgc);
-  if(parseString(map, "cn", cn))   cache.setDescription(cn);
+  if(parseString(map, "name", name)) {
+    // remove html tags we don't want (and don't render, anyway)
+    QTextDocument textDocument;
+    textDocument.setHtml(name);
+    cache.setDescription(textDocument.toPlainText());
+  }
 
-  QString cb;
-  if(parseString(map, "cb", cb))   cache.setOwner(cb);
+  QString owner;
+  if(parseOwner(map, "owner", owner))   cache.setOwner(owner);
 
   QDate dh;
-  if(parseDate(map, "dh", dh))   cache.setDateOfPlacement(dh);
+  if(parseDate(map, "hidden", dh))   cache.setDateOfPlacement(dh);
 
   Rating difficulty, terrain;
-  if(parseRating(map, "d", difficulty))  cache.setDifficulty(difficulty.value());
-  if(parseRating(map, "t", terrain))     cache.setTerrain(terrain.value());
+  if(parseRating(map, "difficulty", difficulty))  cache.setDifficulty(difficulty.value());
+  if(parseRating(map, "terrain", terrain))     cache.setTerrain(terrain.value());
 
   Container container;
-  if(parseContainer(map, "cz", container))  cache.setContainer(container.get());
+  if(parseContainer(map, "container", container))  cache.setContainer(container.get());
 
-  bool ia;
-  if(parseBool(map, "ia", ia)) cache.setAvailable(ia);
+  bool disabled;
+  if(parseBool(map, "disabled", disabled)) cache.setAvailable(!disabled);
  
-  int cid;
-  if(parseInt(map, "cid", cid)) cache.setId(cid);
-
   Cache::Type type;
-  if(parseCtid(map, "ci", type)) cache.setType(type);
+  if(parseType(map, "type", type)) cache.setType(type);
 
-  QString curl, cg;
-  if(parseString(map, "curl", curl)) cache.setUrl(curl);
-  if(parseString(map, "cg", cg))     cache.setGuid(cg);
+  QString g;
+  if(parseString(map, "g", g))     cache.setGuid(g);
 
   qDebug() << __FUNCTION__ << cache;
 
   return true;
 }
 
+bool GcParser::parseStatus(const QMap<QString, QVariant> &map) {
+  QString status;
+
+  if(parseString(map, "status", status))
+    return(status.compare("success") == 0);
+
+  return false;
+}
+
 bool GcParser::decodeInfo(const QString &data, Cache &cache) {
+  QMap<QString, QVariant> map;
+  QList<QVariant> list;
 
   // assume for now that parsing failed for unknown reason
   m_error = tr("Error downloading cache info");
 
-  QString string;
-  if(!decodeStage1(data, string))
+  if(!decodeJson(data, map))
     return false;
 
-  QMap<QString, QVariant> map; 
-  if(!decodeStage2(string, map))
+  if(!parseStatus(map))
     return false;
 
-  if(!parseInfoEntry(map, cache))
+  // the data map contains all information
+  if(!parseList(map, "data", list))
+    return false;
+
+  if(list.size() != 1) {
+    qDebug() << __FUNCTION__ << "list size != 1: " << list.size();
+    return false;
+  }
+
+  if(!parseInfoEntry(list[0].toMap(), cache))
     return false;
 
   m_error = QString();
