@@ -35,7 +35,7 @@ bool None::busy() {
   return false;
 }
 
-void None::processRequestOverview(const QGeoBoundingBox &, const int) {
+void None::processRequestOverview(const QGeoBoundingBox &, const int, const int) {
   qDebug() << PLUGIN_NAME << __FUNCTION__;
   
   CacheList cacheList(PLUGIN_NAME);
