@@ -19,7 +19,7 @@ void Waypoint::setType(const Type &type) {
 QString Waypoint::iconFile() const {
   int i;
 
-  const struct { Waypoint::Type type; QString str; } tags[] = {
+  static const struct { Waypoint::Type type; QString str; } tags[] = {
     { Waypoint::Multistage,   "multistage" },
     { Waypoint::Parking,      "parking" },
     { Waypoint::Final,        "final" },
@@ -55,7 +55,7 @@ Attribute::Attribute(const Id &id, bool yes) {
 QString Attribute::toString() const {
   int i;
 
-  const struct { Attribute::Id type; QString strYes, strNo; } tags[] = {
+  static const struct { Attribute::Id type; QString strYes, strNo; } tags[] = {
      { Attribute::Dogs,
        QObject::tr("Dogs Allowed"),                  QObject::tr("No Dogs Allowed") },
      { Attribute::Fee,
@@ -184,7 +184,7 @@ QString Attribute::toString() const {
 QStringList Attribute::iconFile() const {
   int i;
 
-  const struct { Attribute::Id type; QString str; } tags[] = {
+  static const struct { Attribute::Id type; QString str; } tags[] = {
     { Attribute::Dogs,              "dogs" },
     { Attribute::Fee,               "fee" },
     { Attribute::Rappelling,        "rappelling" },
@@ -275,7 +275,7 @@ bool Log::Type::is(Log::Type::Id id) const {
 QString Log::Type::toString() const {
   int i;
 
-  const struct { Log::Type::Id type; QString str; } tags[] = {
+  static const struct { Log::Type::Id type; QString str; } tags[] = {
     { Log::Type::Found,              QObject::tr("Found it") },
     { Log::Type::NotFound,           QObject::tr("Didn't find it") },
     { Log::Type::Maintenance,        QObject::tr("Owner Maintenance") },
@@ -303,7 +303,7 @@ QString Log::Type::toString() const {
 QString Log::Type::iconFile() const {
   int i;
 
-  const struct { Log::Type::Id type; QString str; } tags[] = {
+  static const struct { Log::Type::Id type; QString str; } tags[] = {
     { Log::Type::Found,              "smile" },
     { Log::Type::NotFound,           "sad" },
     { Log::Type::Maintenance,        "maint" },
@@ -495,7 +495,7 @@ Container::Type Container::get() const {
 QString Container::toString() const {
   int i;
 
-  const struct { Type type; QString str; } tags[] = {
+  static const struct { Type type; QString str; } tags[] = {
     { ContainerRegular,      "Regular" }, { ContainerSmall,   "Small" },
     { ContainerMicro,          "Micro" }, { ContainerOther,   "Other" },
     { ContainerNotChosen, "Not Chosen" }, { ContainerLarge,   "Large" },
@@ -510,7 +510,7 @@ QString Container::toString() const {
 QString Container::iconFile() const {
   int i;
 
-  const struct { Type type; QString str; } tags[] = {
+  static const struct { Type type; QString str; } tags[] = {
     { ContainerRegular,      "regular" }, { ContainerSmall,   "small" },
     { ContainerMicro,          "micro" }, { ContainerOther,   "other" },
     { ContainerNotChosen, "not_chosen" }, { ContainerLarge,   "large" },
@@ -602,7 +602,7 @@ QString Cache::typeString() const {
 QString Cache::typeIconFile() const {
   int i;
 
-  const struct { Type type; QString str; } tags[] = {
+  static const struct { Type type; QString str; } tags[] = {
     { TypeTraditional, "traditional" }, { TypeMulti,       "multi" },
     { TypeMystery,     "mystery" },     { TypeVirtual,     "virtual" },
     { TypeWebcam,      "webcam" },      { TypeEvent,       "event" },
@@ -778,64 +778,3 @@ QDebug operator<<(QDebug debug, const Cache &c) {
 
   return debug;
 }
-
-CacheList::CacheList(const QString &name) {
-  this->m_name = (QString)name;
-}
-
-CacheList::CacheList() {
-}
-
-CacheList::~CacheList() {
-}
-
-void CacheList::append(Cache cache) {
-  QList<Cache>::append(cache);
-}
-
-int CacheList::size() const {
-  return QList<Cache>::size();
-}
-
-Cache CacheList::at(int index) {
-  return QList<Cache>::at(index);
-}
-
-QString CacheList::name() {
-  return m_name;
-}
-
-void CacheList::setName(const QString &name) {
-  m_name = name;
-}
-
-QList<Cache>::const_iterator CacheList::begin() const {
-  return QList<Cache>::begin();
-}
-
-QList<Cache>::const_iterator CacheList::end() const {
-  return QList<Cache>::end();
-}
-
-QList<Cache>::iterator CacheList::begin() {
-  return QList<Cache>::begin();
-}
-
-QList<Cache>::iterator CacheList::end() {
-  return QList<Cache>::end();
-}
-
-void CacheList::clear() {
-  qDebug() << __FUNCTION__;
-
-  QList<Cache>::clear();
-}
-
-void CacheList::setDate(const QDate &date) {
-  m_date = date;
-}
-
-QDate CacheList::date() const {
-  return m_date;
-}
-
