@@ -27,12 +27,14 @@ CacheProvider::RequestEntry::RequestEntry(const RequestType &type, const QString
   this->m_cache = cache;
 }
 
-CacheProvider::RequestEntry::RequestEntry(const RequestType &type, const QGeoBoundingBox &bbox) {
+CacheProvider::RequestEntry::RequestEntry(const RequestType &type, const QGeoBoundingBox &bbox, int zoom, int flags) {
 
   Q_ASSERT(type == Overview);
 
   this->m_type = type;
   this->m_bbox = bbox;
+  this->m_zoom = zoom;
+  this->m_flags = flags;
 }
 
 CacheProvider::RequestEntry::RequestType CacheProvider::RequestEntry::type() {
@@ -43,6 +45,14 @@ QGeoBoundingBox CacheProvider::RequestEntry::bbox() {
   return this->m_bbox;
 }
 
+int CacheProvider::RequestEntry::flags() {
+  return this->m_flags;
+}
+
+int CacheProvider::RequestEntry::zoom() {
+  return this->m_zoom;
+}
+
 QString CacheProvider::RequestEntry::cache() {
   return this->m_cache;
 }
@@ -51,8 +61,10 @@ void CacheProvider::RequestEntry::set(const QString &cache) {
   this->m_cache = cache;
 }
 
-void CacheProvider::RequestEntry::set(const QGeoBoundingBox &bbox) {
+void CacheProvider::RequestEntry::set(const QGeoBoundingBox &bbox, const int zoom, const int flags) {
   this->m_bbox = bbox;  
+  this->m_zoom = zoom;  
+  this->m_flags = flags;  
 }
 
 CacheProvider::RequestQueue::RequestQueue(CacheProvider *cacheProvider) {
@@ -84,20 +96,20 @@ bool CacheProvider::RequestQueue::add(const RequestEntry::RequestType &type, con
   return true;
 }
 
-bool CacheProvider::RequestQueue::add(const RequestEntry::RequestType &type, const QGeoBoundingBox &bbox) {
+bool CacheProvider::RequestQueue::add(const RequestEntry::RequestType &type, const QGeoBoundingBox &bbox, const int zoom, const int flags) {
 
   // check if there's already the same type of request in
   // queue and overwrite that one
   if(size() > 1) {
     for(int i=1;i<size();i++) {
       if(at(i)->type() == type) {
-	at(i)->set(bbox);
+	at(i)->set(bbox, zoom, flags);
 	return false;
       }      
     }
   }
 
-  enqueue(new RequestEntry(type, bbox));
+  enqueue(new RequestEntry(type, bbox, zoom, flags));
   return true;
 }
 
@@ -118,7 +130,8 @@ void CacheProvider::RequestQueue::next() {
     switch(type()) {
     case RequestEntry::Overview:
       qDebug() << __FUNCTION__ << "Pending Overview request";
-      m_cacheProvider->processRequestOverview(head()->bbox()); 
+      m_cacheProvider->processRequestOverview(head()->bbox(), 
+				      head()->zoom(), head()->flags()); 
       break;
 
     case RequestEntry::Info:
@@ -222,19 +235,15 @@ CacheProvider::CacheProvider(QWidget *parent) :
 CacheProvider::~CacheProvider() {
   qDebug() << __FUNCTION__;
 
-#if 0
-  foreach(CacheProviderPlugin *plugin, m_cacheProviderPluginList) 
-    delete plugin;
-#endif
-
   delete this->m_pending;
 }
 
-void CacheProvider::requestOverview(const QGeoBoundingBox &area) {
+void CacheProvider::requestOverview(const QGeoBoundingBox &area, 
+				    int zoom, int flags) {
   qDebug() << __PRETTY_FUNCTION__ << "from" << area.topLeft() << 
-    " to " << area.bottomRight();
+    " to " << area.bottomRight() << "zoom" << zoom;
 
-  if(m_pending->add(RequestEntry::Overview, area))
+  if(m_pending->add(RequestEntry::Overview, area, zoom, flags))
     m_pending->restart();
 }
 
@@ -300,9 +309,9 @@ bool CacheProvider::busy() {
   return m_currentPlugin->busy();
 }
  
-void CacheProvider::processRequestOverview(const QGeoBoundingBox &bbox) {
+void CacheProvider::processRequestOverview(const QGeoBoundingBox &bbox, const int zoom, const int flags) {
   if(m_currentPlugin)
-    m_currentPlugin->processRequestOverview(bbox);
+    m_currentPlugin->processRequestOverview(bbox, zoom, flags);
 }
 
 void CacheProvider::processRequestInfo(const QString &id) {
