@@ -15,6 +15,7 @@
 #include "navigationwindow.h"
 #include "logwindow.h"
 #include "attributewindow.h"
+#include "hintwindow.h"
 #include "iconlabel.h"
 
 #include "swapbox.h"
@@ -23,21 +24,6 @@
 #include "flickcharm.h"
 #endif
 
-class HintWindow : public CustomWindow {
-public:
-  HintWindow(const Cache &cache, QWidget *parent) :
-    CustomWindow("HintWindow", parent) {
-    setWindowTitle(tr("Hint"));
-
-    HtmlView *htmlView = new HtmlView(cache.hint(), this);
-#ifdef FLICKCHARM
-    new FlickCharm(htmlView, this);
-#endif
-
-    setCentralWidget(htmlView);
-  }
-};
-
 void CacheWindow::showHint() {
   HintWindow *hintWindow = new HintWindow(m_cache, this);
   hintWindow->show();
@@ -114,9 +100,9 @@ private:
 
 CacheWindow::CacheWindow(const Cache &cache, 
 	 LocationProvider *locationProvider, 
-	 WaypointDb *wptDb, QWidget *parent) : 
+	 WaypointDb *wptDb, MapWidget *mapWidget, QWidget *parent) : 
   CustomWindow("CacheWindow", parent),  m_cache(cache), m_iconLoader(24),
-  m_locationProvider(locationProvider), m_wptDb(wptDb) {
+  m_locationProvider(locationProvider), m_wptDb(wptDb), m_mapWidget(mapWidget) {
 
   setWindowTitle(cache.name());
 
@@ -233,7 +219,8 @@ void CacheWindow::showDescription() {
 
 void CacheWindow::showNavigation() {
   NavigationWindow *navigationWindow = 
-    new NavigationWindow(m_cache, m_locationProvider, m_wptDb, this);
+    new NavigationWindow(m_cache, m_locationProvider, m_wptDb, 
+			 m_mapWidget, this);
 
   navigationWindow->show();
 }
