@@ -6,13 +6,14 @@
 #include "cache.h"
 #include "iconloader.h"
 #include "htmlview.h"
+#include "mapwidget.h"
 #include "waypointdb.h"
 
 class CacheWindow : public CustomWindow {
   Q_OBJECT;
 
  public:
-  CacheWindow(const Cache &, LocationProvider *, WaypointDb *, QWidget * = 0);
+  CacheWindow(const Cache &, LocationProvider *, WaypointDb *, MapWidget *, QWidget * = 0);
   ~CacheWindow();
 
  private slots:
@@ -27,6 +28,7 @@ class CacheWindow : public CustomWindow {
   IconLoader m_iconLoader;
   LocationProvider *m_locationProvider;
   WaypointDb *m_wptDb;
+  MapWidget *m_mapWidget;
 };
 
 #endif
