@@ -28,7 +28,8 @@ QSize CustomPixmap::prepare(QSvgRenderer *renderer, const QString &name, int siz
 }
 
 // create empty pixmap for graphic effects
-CustomPixmap::CustomPixmap(const QStringList &name, int size, State state) :
+CustomPixmap::CustomPixmap(const QStringList &name, int size, 
+			   State state, qreal angle) :
   QPixmap(size, size) {
 
   m_offset -= QPoint(width()/2, height()/2);
@@ -37,11 +38,12 @@ CustomPixmap::CustomPixmap(const QStringList &name, int size, State state) :
   fill(Qt::transparent);
   this->m_name = name.join(",");
   this->m_state = state;  
+  this->m_angle = angle;  
 }
 
 // create a Pixmap from svg file
 CustomPixmap::CustomPixmap(QSvgRenderer *renderer, 
-	       const QStringList &name, int size) :
+			   const QStringList &name, int size, qreal angle) :
   QPixmap(prepare(renderer, name[0], size)) {
 
   // try to find hotspot object, otherwise just center
@@ -62,10 +64,18 @@ CustomPixmap::CustomPixmap(QSvgRenderer *renderer,
   fill(Qt::transparent);
   this->m_name = name.join(",");
   this->m_state = CustomPixmap::Normal;
+  this->m_angle = angle;
   
   QPainter painter(this);
   painter.setRenderHint(QPainter::Antialiasing, true);
 
+  // do we have to rotate?
+  if(angle != 0.0) {
+    painter.translate( -m_offset );
+    painter.rotate(m_angle);
+    painter.translate( m_offset );
+  }
+
   // draw all given images on top of each other
   QStringList::const_iterator i;
   for(i=name.begin();i!=name.end();i++) {
@@ -88,8 +98,8 @@ CustomPixmap::CustomPixmap(QSvgRenderer *renderer,
 CustomPixmap::~CustomPixmap() {
 }
 
-bool CustomPixmap::is(const QString &name, State state) {
-  return m_name == name && m_state == state;
+bool CustomPixmap::is(const QString &name, State state, qreal angle) {
+  return m_name == name && m_state == state && m_angle == angle;
 }
 
 QPoint CustomPixmap::offset() {
