@@ -289,9 +289,10 @@ void CustomWindow::toggleFullscreen() {
 #endif
 }
 
-void CustomWindow::addMenuEntry(const QString &title, 
+QAction *CustomWindow::addMenuEntry(const QString &title, 
 		QObject *target, const char *slot) {
   QAction *action = new QAction(title, this);
   connect(action, SIGNAL(triggered()), target, slot);
   menuBar()->addAction(action);
+  return action;
 }
