@@ -28,14 +28,14 @@ class CustomWindow : public QMainWindow
   ~CustomWindow();
   void setCentralWidget(QWidget *);
   void setWindowTitle(const QString &);
-  void addMenuEntry(const QString &, QObject *, const char *);
+  QAction *addMenuEntry(const QString &, QObject *, const char *);
   void reParent(CustomWindow *);
 
 #ifdef SYMBIAN_BUTTON_INTERFACE
   virtual void MrccatoCommand(TRemConCoreApiOperationId aOperationId,
 			      TRemConCoreApiButtonAction aButtonAct);
-#endif
   void grabSpecialKeys(bool);
+#endif
   
  protected:
   void keyPressEvent(QKeyEvent*);
@@ -57,12 +57,13 @@ class CustomWindow : public QMainWindow
   IconLoader *m_iconLoader;
   QVBoxLayout *m_layout;
   QLabel *m_title;
-
-  QList <CustomWindow*> m_children;
-
   CustomWindow *m_parent;
 
 #ifdef SYMBIAN_BUTTON_INTERFACE
+  // since the button interface can only be linked to 
+  // one window, we need to keep information on the top window
+  QList <CustomWindow*> m_children;
+
   CRemConInterfaceSelector* iInterfaceSelector;
   CRemConCoreApiTarget*     iCoreTarget;
 #endif
