@@ -6,6 +6,10 @@
 #include "htmlview.h"
 #include "descriptionwindow.h"
 
+#ifdef FLICKCHARM
+#include "flickcharm.h"
+#endif
+
 DescriptionWindow::DescriptionWindow(const Cache &cache, QWidget *parent) : 
   CustomWindow("DescriptionWindow", parent), m_cache(cache) {
 
@@ -17,6 +21,10 @@ DescriptionWindow::DescriptionWindow(const Cache &cache, QWidget *parent) :
 
   addMenuEntry(tr("Open in browser"), this, SLOT(openCacheUrl()));
 
+#ifdef FLICKCHARM
+  new FlickCharm(htmlView, this);
+#endif
+
   setCentralWidget(htmlView);
 }
 
