@@ -12,22 +12,22 @@ IconLoader::IconLoader(int size) {
 }
 
 IconLoader::~IconLoader() {
-  qDeleteAll(pixmapList);
+  qDeleteAll(m_pixmapList);
   delete m_renderer;
 }
 
-CustomPixmap *IconLoader::load(const QStringList &name, int size) {
+CustomPixmap *IconLoader::load(const QStringList &name, int size, qreal angle) {
   QString joinedName = name.join(",");
 
   // check if there's already a matching pixmap in the list
   QList<CustomPixmap*>::const_iterator i;
-  for(i = pixmapList.constBegin(); i != pixmapList.constEnd(); ++i) 
-    if( (*i)->is(joinedName, CustomPixmap::Normal) )
+  for(i = m_pixmapList.constBegin(); i != m_pixmapList.constEnd(); ++i) 
+    if( (*i)->is(joinedName, CustomPixmap::Normal, angle) )
       return *i;
   
   // nothing matching in pixmap list, create a new entry
-  CustomPixmap *pix = new CustomPixmap(m_renderer, name, size?size:m_size); 
-  pixmapList.append(pix);
+  CustomPixmap *pix = new CustomPixmap(m_renderer, name, size?size:m_size, angle); 
+  m_pixmapList.append(pix);
   
   return pix;
 }
@@ -38,7 +38,7 @@ CustomPixmap *IconLoader::loadHighlight(const QStringList &name, int size) {
 
   // check if there's already a matching pixmap in the list
   QList<CustomPixmap*>::const_iterator i;
-  for(i = pixmapList.constBegin(); i != pixmapList.constEnd(); ++i) 
+  for(i = m_pixmapList.constBegin(); i != m_pixmapList.constEnd(); ++i) 
     if( (*i)->is(joinedName, CustomPixmap::Highlight) )
       return *i;
 
@@ -103,7 +103,7 @@ CustomPixmap *IconLoader::loadHighlight(const QStringList &name, int size) {
   hlPainter.drawPixmap(QPointF(BORDER,BORDER), *pix);
 
   // finally add pixmap to cache
-  pixmapList.append(hlPix);
+  m_pixmapList.append(hlPix);
 
   return hlPix;
 }
@@ -118,8 +118,8 @@ CustomPixmap *IconLoader::loadHighlight(const Cache &cache, int size) {
   return loadHighlight(names, size);
 }
 
-CustomPixmap *IconLoader::load(const QString &name, int size) {
-  return load(QStringList(name), size);
+CustomPixmap *IconLoader::load(const QString &name, int size, qreal angle) {
+  return load(QStringList(name), size, angle);
 }
 
 CustomPixmap *IconLoader::loadHighlight(const QString &name, int size) {
