@@ -8,15 +8,19 @@
 #include <QSvgRenderer>
 
 #include "cache.h"
+#include "custompixmap.h"
 
 class IconLoader {
 public:
   IconLoader(int);
   ~IconLoader();
-  QPixmap *load(const QString &, int = 0);
-  QPixmap *load(const QStringList &, int = 0);
-  QPixmap *load(const Cache &, int = 0);
-  QPixmap *load(const Container &, int = 0);
+  CustomPixmap *load(const QString &, int = 0, qreal = 0.0);
+  CustomPixmap *loadHighlight(const QString &, int = 0);
+  CustomPixmap *load(const QStringList &, int = 0, qreal = 0.0);
+  CustomPixmap *loadHighlight(const QStringList &, int = 0);
+  CustomPixmap *load(const Cache &, int = 0);
+  CustomPixmap *loadHighlight(const Cache &, int = 0);
+  CustomPixmap *load(const Container &, int = 0);
   int size() const;
   QWidget *newWidget(const QString &, int = 0);
   QWidget *newWidget(const QStringList &, int = 0);
@@ -26,20 +30,7 @@ private:
   QSvgRenderer *m_renderer;
   int m_size;
   
-  class Pixmap {
-  public:
-    Pixmap(QSvgRenderer *, const QStringList &, int = 0);
-    ~Pixmap();
-    QPixmap *pixmap();
-    bool is(const QString &);
-    bool load(QSvgRenderer *, const QString &);
-
-  private:
-    QPixmap *m_pixmap;
-    QString m_name;
-  };
-
-  QList <Pixmap*> pixmapList;
+  QList <CustomPixmap*> m_pixmapList;
 };
 
 #endif // ICON_LOADER_H
