@@ -3,9 +3,7 @@
 
 #include <QGeoPositionInfoSource>
 
-#ifndef Q_WS_WIN
 #include <QCompass>
-#endif
 
 QTM_USE_NAMESPACE
 
@@ -18,21 +16,15 @@ class LocationProvider : public QObject {
 
  private slots:
   void positionHasBeenUpdated(const QGeoPositionInfo &);
-#ifndef Q_WS_WIN
   void checkCompassReading();
-#endif
 
  signals:
   void positionUpdated(const QGeoPositionInfo &);
-#ifndef Q_WS_WIN
   void positionUpdated(const QCompassReading *);
-#endif
 
  private:
   QGeoPositionInfoSource *m_location;
-#ifndef Q_WS_WIN
   QCompass *m_compass;
-#endif
 };
 
 #endif // LOCATIONPROVIDER_H
