@@ -4,7 +4,9 @@
 #include <QMessageBox>
 #include <QPushButton>
 #include <QDesktopServices>
+#include <QNetworkReply>
 #include <QUrl>
+#include <QXmlStreamReader>
 
 #include "mainwindow.h"
 #include "mapwidget.h"
@@ -13,6 +15,11 @@
 #include "cachewindow.h"
 #include "config.h"
 #include "tool.h"
+#include "htmlview.h"
+
+#ifdef FLICKCHARM
+#include "flickcharm.h"
+#endif
 
 #include <QIcon>
 #include <QSettings>
@@ -46,6 +53,10 @@ void MainWindow::enableToolProjection(bool on) {
 void MainWindow::createMenu() {
 
   addMenuEntry(tr("&About"), this, SLOT(about()));
+
+  m_motdAction = addMenuEntry(tr("&MotD"), this, SLOT(motd()));
+  m_motdAction->setEnabled(false);
+
   addMenuEntry(tr("&Settings"), this, SLOT(settingsdialog()));
 
   /* create a submenu for the plugin selection */  
@@ -54,10 +65,67 @@ void MainWindow::createMenu() {
   /* add tools to the tools menu */
   QMenu *toolsMenu = menuBar()->addMenu(tr("&Tools"));
   ToolRot13::registerMenu(toolsMenu, this, SLOT(launchToolRot13()));
-  m_ActionToolProjection = ToolProjection::registerMenu(toolsMenu, this, SLOT(launchToolProjection()));
+  m_ActionToolProjection = 
+    ToolProjection::registerMenu(toolsMenu, this, SLOT(launchToolProjection()));
   m_ActionToolProjection->setEnabled(false);
 }
 
+static void drop(QXmlStreamReader &xml) {
+  xml.readNext();
+  
+  while(xml.tokenType() != QXmlStreamReader::EndElement &&
+	!xml.atEnd() && !xml.hasError()) {
+
+    if(xml.tokenType() == QXmlStreamReader::StartElement) 
+      drop(xml);
+
+    xml.readNext();
+  }
+}
+
+void MainWindow::replyFinished(QNetworkReply *reply) {
+  // invoke appropriate decoder
+  if(reply->isFinished()) {
+    QString allData = QString::fromUtf8(reply->readAll());
+
+    // send reply through xml parser to extract message and version
+    QXmlStreamReader xml(allData);
+    while(!xml.atEnd() && !xml.hasError()) {
+      xml.readNext();
+      
+      if(xml.tokenType() == QXmlStreamReader::StartDocument) 
+	continue;
+      
+      if(xml.tokenType() == QXmlStreamReader::StartElement) {
+	if(xml.name() == "motd") {
+
+	  int version = xml.attributes().value("version").toString().toInt();
+	  m_motd = xml.readElementText().simplified();	  
+
+	  /* check if this is a new message */
+	  if(version > m_motdVersion) {
+	    motd();
+	    m_motdVersion = version;
+	  }
+
+	  if(!m_motd.isEmpty()) 
+	    m_motdAction->setEnabled(true);
+	} else 
+	  drop(xml);
+      }
+    }
+      
+      /* Error handling. */
+    if(xml.hasError()) 
+      qDebug() << __FUNCTION__ << QString("Parse error at line %1, column %2:\n%3")
+	.arg(xml.lineNumber()).arg(xml.columnNumber()).arg(xml.errorString());
+    
+    xml.clear();
+  }
+
+  reply->deleteLater();
+}
+
 void MainWindow::settingsdialog() {
   qDebug() << __FUNCTION__;
 
@@ -103,10 +171,26 @@ void MainWindow::about() {
 	   );
 }
 
+void MainWindow::motd() {
+  if(!m_motd.isEmpty()) {
+    Description motd;
+    motd.set(true, m_motd);
+    
+    CustomWindow *motdWin = new CustomWindow("MotdWindow", this);
+    motdWin->setWindowTitle(tr("Message of the day"));
+    HtmlView *htmlView = new HtmlView(motd, motdWin);
+#ifdef FLICKCHARM
+    new FlickCharm(htmlView, this);
+#endif
+    
+    motdWin->setCentralWidget(htmlView);
+    motdWin->show();
+  }
+}
 
 MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) : 
   CustomWindow("MainWindow", parent), m_locationProvider(locationProvider),
-  m_lastFlags(0), m_ActionToolProjection(NULL) {
+  m_lastFlags(0), m_ActionToolProjection(NULL), m_motdVersion(0) {
 
   qDebug() << __FUNCTION__;
   m_cacheProvider = new CacheProvider(this);
@@ -131,6 +215,7 @@ MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) :
   settings.beginGroup("Map");
   QString serviceProviderStr = settings.value("Service", "nokia").toString();
   settings.endGroup();
+  m_motdVersion = settings.value("motdVersion", 0).toInt();
 
   // give app id key to service provider
   QMap<QString, QVariant> params;
@@ -224,11 +309,28 @@ MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) :
 		  QDate::fromString(EXPIRATION_DATE, "ddMMyyyy"))));
   }
 #endif  
+
+  // fetch "message of the day" from harbaum.org
+
+  // setup network manager and listen for its replies
+  this->m_manager = new QNetworkAccessManager(this);
+  connect(this->m_manager, SIGNAL(finished(QNetworkReply*)),
+	  this, SLOT(replyFinished(QNetworkReply*)));
+
+  QNetworkRequest request;
+  request.setRawHeader("User-Agent", "CacheMe " VERSION);
+  request.setUrl(QUrl("http://www.harbaum.org/till/cacheme/motd.xml"));
+  this->m_manager->get(request);
 }
 
 MainWindow::~MainWindow() {
   qDebug() << __FUNCTION__;
 
+  // save motd version
+  QSettings settings;
+  settings.setValue("motdVersion", m_motdVersion);
+
+  delete m_manager;
   delete m_wptDb;
   delete m_cacheProvider;
   delete m_serviceProvider;
@@ -257,7 +359,8 @@ void MainWindow::reloadCaches() {
     return;
 
   // request new caches for the maps new viewport
-  m_cacheProvider->requestOverview(this->m_mapWidget->viewport(), m_lastFlags);
+  m_cacheProvider->requestOverview(this->m_mapWidget->viewport(), 
+				   this->m_mapWidget->zoomLevel(), m_lastFlags);
 }
 
 void MainWindow::reloadCaches(const int flags) {
@@ -268,7 +371,8 @@ void MainWindow::reloadCaches(const int flags) {
     return;
 
   // request new caches for the maps new viewport
-  m_cacheProvider->requestOverview(this->m_mapWidget->viewport(), flags);
+  m_cacheProvider->requestOverview(this->m_mapWidget->viewport(), 
+				   this->m_mapWidget->zoomLevel(), flags);
 }
 
 void MainWindow::updateCaches(const CacheList &cacheList) {
