@@ -191,6 +191,7 @@ void MapWidget::hideBubble() {
     m_bubble = NULL;
 
     this->m_mapOverlay->enableForwardButton(false);
+    emit cacheIsSelected(false);
   }
 }
 
@@ -200,7 +201,10 @@ void MapWidget::showBubble(const Cache &cache) {
   hideBubble();
   m_bubble = new MapBubble(this, size().width() > size().height(), cache);
   addMapObject(m_bubble);
-  this->m_mapOverlay->enableForwardButton(cache.url().isValid());
+
+  bool isValid = cache.url().isValid();
+  this->m_mapOverlay->enableForwardButton(isValid);
+  emit cacheIsSelected(isValid);
 }
 
 void MapWidget::showBubble(const Waypoint &wpt) {
@@ -211,6 +215,13 @@ void MapWidget::showBubble(const Waypoint &wpt) {
   addMapObject(m_bubble);
 
   this->m_mapOverlay->enableForwardButton(false);
+  emit cacheIsSelected(false);
+}
+
+Cache MapWidget::selectedCache() {
+  Q_ASSERT(m_bubble);
+
+  return m_bubble->cache();
 }
 
 // currently connected to the "forward" button
@@ -333,12 +344,14 @@ MapWidget::MapCacheObject::MapCacheObject(IconLoader *loader, const Cache &cache
   setProperty("name", cache.name());
 };
 
+#ifdef WORKAROUND_CONTAINS
 // the pixmap object seems to actually check for clicks onto the bitmap. thus
 // we only check for the click being withing the entire pixmap size. furthermore
 // the pixmap precise stuff doesn't seem to work at all on the n900/maemo
 bool MapWidget::MapCacheObject::contains(const QGeoCoordinate &coo) const {
   return boundingBox().contains(coo);
 }
+#endif
 
 MapWidget::MapWaypointObject::MapWaypointObject(IconLoader *loader, 
 		const QString &cacheName, const Waypoint &waypoint) :
@@ -361,9 +374,11 @@ Waypoint MapWidget::MapWaypointObject::waypoint() const {
   return m_wpt;
 }
 
+#ifdef WORKAROUND_CONTAINS
 bool MapWidget::MapWaypointObject::contains(const QGeoCoordinate &coo) const {
   return boundingBox().contains(coo);
 }
+#endif
 
 #include <QGraphicsScene>
 #include <QGraphicsView>
@@ -401,16 +416,19 @@ bool MapWidget::mapWindowIsActive() {
   return windowIsActive;
 }
 
-void MapWidget::updateCaches(const CacheList &cacheList) {
+void MapWidget::updateCaches(const CacheList &cacheListIn) {
   static bool tooOld = false;
 
   if(!mapWindowIsActive()) {
     qDebug() << __FUNCTION__ << "delaying update";
     m_cacheListWasUpdated = true;
-    m_cacheList2Update = cacheList;
+    m_cacheList2Update = cacheListIn;
     return;
   }
 
+  // create a local non-const copy as me may have to sort it
+  CacheList cacheList(cacheListIn);  
+
   // save cache if existing bubble
   Cache bubbleCache;
   Waypoint bubbleWaypoint;
@@ -433,9 +451,26 @@ void MapWidget::updateCaches(const CacheList &cacheList) {
   } else if(tooOld && weekAge == 0)
     tooOld = false;
 
+  if(cacheList.size() > CACHELIST_LIMIT) {
+    emit showMessage(tr("Limiting number of displayed caches"));
+
+    qDebug() << __FUNCTION__ << "limiting cache list of" << 
+      cacheList.size() << "to" << CACHELIST_LIMIT;
+
+    // remove everything not on screen
+    cacheList.clip(viewport());
+    qDebug() << __FUNCTION__ << "size after clipping" << cacheList.size();
+
+    if(cacheList.size() > CACHELIST_LIMIT) {
+      // sort with respect to map center
+      cacheList.sort(center());
+    }
+  }
+
   // draw all new caches
   QList<Cache>::const_iterator i;
-  for( i = cacheList.begin(); i != cacheList.end(); ++i ) {
+  int j;
+  for( j=0, i = cacheList.begin(); j < CACHELIST_LIMIT && i != cacheList.end(); ++j, ++i ) {
     // show if nno found/owned are to be hidden or if the cache is neither found nor owned 
     if(!m_hideOwn || (!i->owned().isSetAndTrue() && !i->found().isSetAndTrue())) {
 
@@ -498,6 +533,10 @@ void MapWidget::reloadTimerExpired() {
   }
 }
 
+bool MapWidget::preparingReload() {
+  return this->m_timer->isActive();
+}
+
 void MapWidget::reload() {
   // start the timer if it's not already running, re-start from zero otherwise
   // using less than 1000ms here makes sure that requests are being sent for
@@ -518,11 +557,7 @@ void MapWidget::positionUpdated(const QCompassReading *reading) {
   if(reading->calibrationLevel() > 0.9) {
     qreal newVal = reading->azimuth();
     if(newVal != m_compass) {
-      QPixmap *markerIcon = m_iconLoader->load("gps_arrow");
-
-      // todo: rotate markerIcon
-
-      
+      QPixmap *markerIcon = m_iconLoader->load("gps_arrow", 0, newVal);
 
       if(m_gpsMarker) m_gpsMarker->setPixmap(*markerIcon);
       m_compass = newVal;
@@ -575,6 +610,13 @@ QString MapWidget::managerName() {
   return m_manager->managerName();
 }
 
+QGeoCoordinate MapWidget::gpsCoordinate() {
+  if(!m_gpsMarker || !m_gpsMarker->isVisible()) 
+    return QGeoCoordinate();
+
+  return m_gpsMarker->coordinate();
+}
+
 void MapWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget * widget) {
   // first call parents paint function
   QGraphicsGeoMap::paint(painter, option, widget);
