@@ -88,6 +88,7 @@ QWidget *SettingsDialog::createMapTab() {
 #endif
 
   QGridLayout *mapTabLayout = new QGridLayout;
+  mapTabLayout->setSpacing(0);
   mapTab->setLayout(mapTabLayout);
 
   const QString mapTypeStr[] = {
@@ -165,6 +166,7 @@ QWidget *SettingsDialog::createAccountTab() {
 #endif
 
   QVBoxLayout *accountTabLayout = new QVBoxLayout;
+  accountTabLayout->setSpacing(0);
   accountTab->setLayout(accountTabLayout);
 
   /* ------------------- user configuration --------------------- */
@@ -175,12 +177,16 @@ QWidget *SettingsDialog::createAccountTab() {
   QLabel *accountTitle = new QLabel(tr("Geocaching.com account"));
   accountTabLayout->addWidget(accountTitle);
 
+  accountTabLayout->addStretch(1);
+
   /* -------------- user name entry --------------- */
 
   accountTabLayout->addWidget(new QLabel(tr("Username") + ":"));
   m_name = new QLineEdit(settings.value("Name", "").toString());
   accountTabLayout->addWidget(m_name);
 
+  accountTabLayout->addStretch(1);
+
   /* -------------- password entry --------------- */
   accountTabLayout->addWidget(new QLabel(tr("Password") + ":"));
   m_password = 
@@ -188,6 +194,8 @@ QWidget *SettingsDialog::createAccountTab() {
   m_password->setEchoMode(QLineEdit::PasswordEchoOnEdit);
   accountTabLayout->addWidget(m_password);
 
+  accountTabLayout->addStretch(1);
+
   settings.endGroup();
 
   return accountTab;
@@ -202,6 +210,8 @@ SettingsDialog::SettingsDialog(MapWidget *mapWidget,
   setWindowTitle(tr("Settings"));
 
   QVBoxLayout *mainLayout = new QVBoxLayout;
+  mainLayout->setContentsMargins(0,0,0,0);
+  mainLayout->setSpacing(0);
 
 #ifdef USE_TABS
   /* topics are sorted into tabs */
