@@ -10,7 +10,7 @@
 #include "mapwidget.h"
 
 class SettingsDialog : public QDialog {
-Q_OBJECT
+ Q_OBJECT
 
  public:
   SettingsDialog(MapWidget *, CacheProvider *, QWidget * = 0);
@@ -19,12 +19,16 @@ Q_OBJECT
   void applyChanges();
 
  private:
+  QWidget *createMapTab();
+  QWidget *createAccountTab();
+
   MapWidget *m_mapWidget;
   QComboBox *m_typeCombo;
   QComboBox *m_serviceCombo;
   QLineEdit *m_name;
   QLineEdit *m_password;
   QCheckBox *m_hiRez;
+  QCheckBox *m_disableScreensaver;
   QCheckBox *m_hideOwn;
 };
 
